<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="sk" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategória:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Spustiť torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Preskočiť kontrolu hash</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Vytvoriť podzložku</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Magnet mód torrentu</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Všetky</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Bez kategórie</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Pridať kategóriu...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Odstrániť kategóriu</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Odstrániť nepoužívané kategórie</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Obnoviť torrenty</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Pozastaviť torrenty</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Zmazať torrenty</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nová kategória</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Upraviť kategóriu...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Ukončiť qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Iba jeden odkaz na riadok</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Globálne obmedzenie na rýchlosť nahrávania musí byť väčšie ako 0 alebo vypnuté.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Globálne obmedzenie na rýchlosť sťahovania musí byť väčšie ako 0 alebo vypnuté.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatívne obmedzenie na rýchlosť nahrávania musí byť väčšie ako 0 alebo vypnuté.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatívne obmedzenie na rýchlosť sťahovania musí byť väčšie ako 0 alebo vypnuté.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maximálny počet aktívnych sťahovaní musí byť väčší ako -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maximálny počet aktívnych nahrávaní musí byť väčší ako -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maximálny počet aktívnych torrentov musí byť väčší ako -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Maximálny počet spojení musí byť väčší ako 0 alebo vypnutý.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Maximálny počet spojení na torrent musí byť väčší ako 0 alebo vypnutý.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Maximálny počet nahrávacích pozící musí byť väčší ako 0 alebo vypnutý.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Nepodarilo sa uložiť nastavenia programu, qBittorrent je pravdepodobne nedostupný.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent na Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámy</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Limit ratia musí byť v rozsahu od 0 do 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Doba seedovania musí byť v rozsahu od 0 do 525600 minút.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Port pre prichádzajúce spojenia musí byť medzi 1 a 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Port pre webové rozhranie musí byť medzi 1 a 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Nepodarilo sa prihlásiť, qBittorrent je pravdepodobne nedosiahnuteľný.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nesprávne užívateľské meno alebo heslo.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Prihlasovacie meno</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Pôvodní autori</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Použiť</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Nahrať torrenty</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Uložiť súbory do priečinka:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Cookie:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Napíšte sem názov priečinku</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Ďalšie informácie</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informácie o certifikátoch</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nastaviť umiestnenie</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Obmedziť rýchlosť nahrávania</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Obmedziť rýchlosť sťahovania</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Premenovať torrent</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Iné...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pondelok</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Utorok</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Streda</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Štvrtok</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Piatok</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Nedeľa</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Odhlásenie</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Stiahnuť torrenty z ich URL alebo odkazov Magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Nahrať lokálny torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Ste si istý, že chcete zmazať vybrané torrenty zo zoznamu prenosov?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Klient qBittorrent nie je dostupný</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Celkový počet nahrávacích slotov musí byť väčší ako 0 alebo vypnutý.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Neplatný názov kategórie:\nProsím nepoužívajte žiadne špeciálne znaky ani diakritiku v názve kategórie.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Nie je možné vytvoriť kategóriu</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Obmedzenie rýchlosti nahrávania musí byť väčšie ako 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upraviť</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Voľné miesto: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Časovač nečinnosti torrentu musí byť väčší ako 0:</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Správa ukladania</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Obmedzenie rýchlosti sťahovania musí byť väčšie ako 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent bol ukončený</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Úpravy</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Nástroje</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomocník</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Zobraziť</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Možnosti...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Najnižšia priorita</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Najvyššia priorita</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Znížiť prioritu</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Zvýšiť prioritu</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Panel nástrojov</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Stavový riadok</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Rýchlosť v titulnom pruhu</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Prispejte!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Pokračovať všetky</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Štatistika</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Zmazať</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Pozastaviť všetky</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Pridať torrentový súbor...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentácia</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Pridať torrentový súbor...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Globálne rýchlostné obmedzenie nahrávania</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Globálne rýchlostné obmedzenie sťahovania</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Ste si istý, že chcete ukončiť qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[S: %1, N: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatívne rýchlostné obmedzenia</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Vyhľadávač</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtruj zoznam torrentu...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Vyhľadávanie</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Prenosy</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Možnosti</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Sťahovanie</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Spojenie</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rýchlosť</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>Bittorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Web UI</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Jazyk</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Jazyk používateľského rozhrania:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Upozornenie o dokončení sťahovania emailom</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Po dokončení sťahovania spustiť externý program</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP filterovanie</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Naplánovať použitie alternatívnych rýchlostných obmedzení</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Zaraďovanie torrentu do fronty</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Seedovať torrenty pokým doba nedosiahne</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Automaticky pridať tieto trackery k novým sťahovaniam:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Zapnúť webové rozhranie (vzdialené ovládanie)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP adresa:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Serverové domény:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Používať HTTPS namiesto HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Obísť autentifikáciu pri prihlasovaní z lokálneho počítača</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Preskočiť overenie klientov na zozname povolených IP podsietí</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Aktualizovať môj dynamický doménový názov </translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Ponechať neúplné torrenty v:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopírovať .torrent súbory do:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopírovať .torrent súbory po dokončení sťahovania do:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Dopredu alokovať miesto pre všetky súbory</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Pridať príponu .!qB k nedokončeným súborom</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Automaticky pridať torrenty z:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP server:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Tento server vyžaduje zabezpečené pripojenie (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentifikácia</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Meno používateľa:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Heslo:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Povolený protokol:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP a μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Počúvať na porte</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port pre prichádzajúce spojenia:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Použiť presmerovanie portov UPnP/NAT-PMP z môjho routera</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Použiť pri každom spustení iný port</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Obmedzenia spojení</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maximálny počet spojení na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Maximálny celkový počet spojení:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maximálny počet slotov pre nahrávanie na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Maximálny celkový počet slotov na nahrávanie:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy server</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(žiadny)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Používať proxy na spojenia s rovesníkmi</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Zakázať spojenia, ktoré proxy nepodporujú</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Používať proxy len na torrenty.</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Cesta k filtrom (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuálne zablokované IP adresy...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Použiť na trackery</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Globálne rýchlostné obmedzenia</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Nahrávanie:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Sťahovanie:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatívne rýchlostné obmedzenia</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Od:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Do:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Kedy:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Každý deň</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Dni v týždni</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Víkendy</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Nastavenia rýchlostných obmedzení</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Použiť rýchlostné obmedzenie na réžiu prenosu</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Použiť obmedzenie rýchlosti na protokol µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Súkromie</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Zapnúť DHT (decentralizovaná sieť) - umožní nájsť viac peerov</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Zapnúť Peer eXchange (PeX) - umožní nájsť viac peerov</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Zapnúť Local Peer Discovery - umožní nájsť viac peerov</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Režim šifrovania:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Uprednostňovať šifrovanie</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Vyžadovať šifrovanie</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Vypnúť šifrovanie</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Zapnúť anonymný režim</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Maximálny počet aktívnych sťahovaní:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maximálny počet aktívnych nahrávaní:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maximálny počet aktívnych torrentov:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Nepočítať pomalé torrenty do týchto obmedzení</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Obmedzenie ratia</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Seedovať torrenty pokým nedosiahne ratio</translation>
    </message>
    <message>
        <source>then</source>
        <translation>potom</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Pozastaviť ich</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Odstrániť ich</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Použiť presmerovanie portov UPnP/NAT-PMP z môjho routera</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certifikát:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Kľúč:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Zaregistrovať sa</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Názov domény:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Podporované voľby (citlivé na veľkosť písmen)</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Názov torrentu</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategória</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Značky (oddelené čiarkou)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Cesta k obsahu (rovnaká ako koreňová cesta k torrentu s viacerými súbormi)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Koreňová cesta (cesta prvého podadresára torrentu)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Uložiť do</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Počet súborov</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Veľkosť torrentu (v bajtoch)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Aktuálny tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tip: Ohraničiť parameter úvodzovkami, aby nedošlo k odstrihnutiu textu za medzerou (napr. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Používateľské meno pre webové rozhranie musí mať dĺžku aspoň 3 znaky.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Heslo pre webové rozhranie musí mať dĺžku aspoň 6 znakov.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minút</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Zapnúť ochranu clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Zapnúť ochranu Cross-Site Request Forgery (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Vymazať .torrent súbory po pridaní</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Limit rýchlosti sťahovania:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Limit rýchlosti odosielania:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Zmena aktuálneho hesla</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Použiť alternatívne Web UI</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Predvolená cesta pre ukladanie:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Umiestnenie súborov Alternatívneho UI nemôže byť prázdne.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Pridať torrent do zoznamu sťahovaných ako pozastavený</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Prepni torrent do manuálneho režimu</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Ak sa zmení kategória torrentu:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Premiestni torrenty, ktorých sa zmena týka</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Použiť rýchlostné obmedzenie na peerov v LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 znamená neobmedzené</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Premiestni torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Ak sa zmení predvolená cesta pre ukladanie:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Zapnúť overovanie hlavičky hostiteľa</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Zabezpečenie</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Ak sa zmení cesta pre ukladanie kategórie:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Vytvoriť podadresár pre torrent s viacerými súbormi</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekundy</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Prepni torrenty, ktorých sa zmena týka, do manuálneho režimu</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Umiestnenie súborov:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuálny</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Časovač nečinnosti torrentu:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Prednastavený režim správy torrentov:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Pri pridávaní torrentu</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Príznaky</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Spojenie</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Priebeh</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Rýchlosť sťahovania</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Rýchlosť nahrávania</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Nahrané</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Dôležitosť:</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Súbory</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Krajina</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normálna</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Vysoká</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maximálna</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackery</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Peeri</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP zdroje</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Stiahnuté:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Prenos</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Čas aktivity:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Odhad. čas:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Nahrané:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Seedov:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Sťahovaná rýchlosť:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Nahrávaná rýchlosť:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Peeri</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Obmedzenie sťahovania:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Obmedzenie nahrávania:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Premrhané:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Spojenie:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informácie</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentár:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Ratio:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Znova ohlásiť o:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Posledné videné ukončenie:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Celková veľkosť:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Častí:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Vytvoril:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Pridané:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Dokončené:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Vytvorené:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash torrentu:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Uložené do:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nikdy</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (máte %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 toto sedenie)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 max.)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 celkom)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 priem.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Limit na sťahovanie:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Limit pre nahrávanie:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Sledovaný priečinok</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Prepísať umiestnenie pre uloženie</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Sledovaný priečinok</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Predvolená cesta pre ukladanie</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Štatistika</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Štatistika používateľa</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Štatistika vyrovnávacej pamäte</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Čítaní z vyrovnávacej pamäte:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Priemerný čas vo fronte:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Pripojení peeri:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Celkové ratio:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Celkovo stiahnuté:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Zahodené od spustenia:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Celkovo odoslané:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Celková veľkosť bufferov:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Štatistika činnosti</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>I/O úlohy zaradené do frontu:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Preťaženie vyrovnávacej pamäte zápisu:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Preťaženie vyrovnávacej pamäte čítania:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Celková veľkosť frontu:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 uzlov</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Všetky (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Sťahované (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Seedované (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Dokončené (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Obnovené (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Pozastavené (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktívne (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Neaktívne (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Chybných (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Všetky (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Sťahované (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Seedované (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Dokončené (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Pozastavené (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Obnovené (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktívne (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Neaktívne (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Chybných (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Priebeh</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Priorita sťahovania</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Ostáva</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Dostupnosť</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Hotovo</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seedov</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Peerov</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Rýchlosť sťahovania</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Rýchlosť nahrávania</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Ratio</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Odhad. čas</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Značky</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Pridané</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Dokončené</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limit sťah.</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limit nahr.</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Nahraté</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Stiahnuté od spustenia</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Nahraté od spustenia</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Ostáva</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Čas aktivity</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Uložiť do</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Dokončené</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Obmedzenie pomeru zdieľania</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Posledné videné ukončenie</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Posledná aktivita</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Celková veľkosť</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Rovesníci</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Správa</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Stiahnuté</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>URL trackera:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Prebieha aktualizácia...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Funkčné</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Vypnuté</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Zatiaľ nekontaktovaný</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Neuvedené</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seedov</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Nefunguje</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Skopírovať URL trackera</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Pridať nový tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Upraviť URL trackera...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Úprava trackera</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Leecheri</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Odstrániť tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Dialóg pre pridanie torrentu</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Pridať nasledovné trackery (jeden tracker na riadok):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>pred %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Prebieha alokácia</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pozastavené</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Dokončené</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Presunúť</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Seeduje sa</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Seeduje sa</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Vo fronte</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Chybných</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Sťahuje sa</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Sťahujú sa metadáta</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Prebieha kontrola</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Chýbajúce súbory</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Vo fronte na kontrolu</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Sťahovanie</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Kontrolujú sa dáta na obnovenie sťahovania</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Bez pohybu</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Stav</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategórie</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Obmedzenie rýchlosti sťahovania torrentu</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Obmedzenie rýchlosti nahrávania torrentu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Premenovať</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Vynútiť pokračovanie</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Pozastaviť</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Zmazať</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Obmedzenie pomeru zdieľania...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Obmedziť rýchlosť nahrávania...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Obmedziť rýchlosť sťahovania...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Presunúť vyššie</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Presunúť nižšie</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Presunúť navrch</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Presunúť na spodok</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Nastaviť cieľ...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopírovať názov</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Kopírovať hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Sťahovať najprv prvú a poslednú časť</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatický režim správy torrentov</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nová...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Vrátiť pôvodné</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorita</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Vynútiť opätovnú kontrolu</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopírovať magnet URI</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Režim super seedovania</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Premenovať...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Sťahovať v poradí</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Vynútiť opätovnú kontrolu</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nová kategória</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Umiestnenie</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nový názov:</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nastaviť umiestnenie</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Vynútiť znovuohlásenie</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Upraviť kategóriu</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Uložiť do</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Obmedzenie pomeru odoslaných/stiahnutých dát torrentu</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Nastavenie globálneho limitu zdieľania</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Nastaviť zdieľanie bez limitu</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Nastaviť limit zdieľania na</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>ratio</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minút</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Pokročilý klient siete BitTorrent naprogramovaný v C++, založený na sade nástrojov Qt a knižnici libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Domovská stránka</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Fórum: </translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Sledovanie chýb:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Potvrdenie zmazania</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Zmazať aj súbory na pevnom disku</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Potvrdenie zmazania - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Stiahnuť z viacerých URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stiahnuť</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Pridať odkazy torrentov</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Neznáma</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Cesta pre uloženie je prázdna</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Cesta k pluginu:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>URL alebo miestny priečinok</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Inštalovať plugin</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seedov:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Všetky pluginy</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Veľkosť:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastaviť</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Vyhľadávanie</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Zásuvné moduly vyhľadávania</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Všetky kategórie</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Hľadať v:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Skopíruj URL stránky popisu</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Prejsť na stránku popisu</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Výsledky</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Stiahnuť</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Iba názvy torrentov</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Iba povolené</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>mimo</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Všade</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Odinštalovať</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Nainštalovať nový plugin</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Nové vyhľadávacie pluginy môžete získať tu:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zatvoriť</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Inštalované pluginy vyhľadávania:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Zapnuté</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Varovanie: Uistite sa, že dodržiavate zákony Vašej krajiny o ochrane duševného vlastníctva keď sťahujete torrenty z ktoréhokoľvek z týchto vyhľadávačov.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Skontrolovať aktualizácie</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Pluginy vyhľadávania</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Leecheri</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Vyhľadávač</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seederi</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Zapnuté</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzia</translation>
    </message>
</context>
</TS>